@@ -99,7 +99,7 @@ namespace Rstats {
   }
 
   namespace Util {
-    SV* args(SV*, SV*);
+    SV* args(SV*, SV*, SV*);
     IV is_perl_number(SV*);
     SV* cross_product(SV*);
     SV* pos_to_index(SV*, SV*);
@@ -307,6 +307,12 @@ namespace Rstats {
     std::map<IV, IV>* na_positions;
     void* values;
   };
+  
+  template <typename T>
+  struct Vector2 {
+    std::vector<T>* values;
+    std::map<IV, IV>* na_positions;
+  };
 
   // Macro for Rstats::Vector
 # define RSTATS_DEF_VECTOR_FUNC_UN_IS(FUNC_NAME, ELEMENT_FUNC_NAME) \
@@ -594,6 +600,67 @@ namespace Rstats {
     bool is_numeric (Rstats::Vector*);
     bool is_logical (Rstats::Vector*);
     
+    template <typename T>
+    Rstats::Vector2<T>* new_vector2 (IV length) {
+      Rstats::Vector2<T>* v1 = new Rstats::Vector2<T>;
+      v1->values = new std::vector<T>(length);
+      v1->na_positions = new std::map<IV, IV>;
+      
+      return v1;
+    }
+    
+    template <typename T>
+    std::vector<T>* get_values2(Rstats::Vector2<T>* v1) {
+      return (std::vector<T>*)v1->values;
+    }
+    
+    template <typename T>
+    IV get_length2 (Rstats::Vector2<T>* v1) {
+      if (v1->values == NULL) {
+        return 0;
+      }
+      
+      return Rstats::VectorFunc::get_values2(v1)->size();
+    }
+    
+    template <typename T>
+    void set_value2(Rstats::Vector2<T>* v1, IV pos, T value) {
+      (*Rstats::VectorFunc::get_values2(v1))[pos] = value;
+    }
+    
+    template <typename T>
+    void add_na_position2(Rstats::Vector2<T>* v1, IV position) {
+      (*v1->na_positions)[position] = 1;
+    }
+    
+    template <typename T2, typename T1>
+    void merge_na_positions2(Rstats::Vector2<T2>* v2, Rstats::Vector2<T1>* v1) {
+      for(std::map<IV, IV>::iterator it = v1->na_positions->begin(); it != v1->na_positions->end(); ++it) {
+        Rstats::VectorFunc::add_na_position2(v2, it->first);
+      }
+    }
+    
+    template <typename T>
+    T get_value2(Rstats::Vector2<T>* v1, IV pos) {
+      return (*Rstats::VectorFunc::get_values2(v1))[pos];
+    }
+    
+    template <typename T_func, typename T_out, typename T_in>
+    Rstats::Vector2<T_out>* operate_un_math(T_func func, Rstats::Vector2<T_in>* v1) {
+      IV length = Rstats::VectorFunc::get_length2(v1);
+      Rstats::Vector2<T_out>* v2 = Rstats::VectorFunc::new_vector2<T_out>(length);
+      for (IV i = 0; i < length; i++) {
+        Rstats::VectorFunc::set_value2(v2, i, func(Rstats::VectorFunc::get_value2(v1, i)));
+      }
+      Rstats::VectorFunc::merge_na_positions2(v2, v1);
+      return v2;
+    }
+    
+    void sin2(Rstats::Vector2<SV*>* v1);
+    Rstats::Vector2<std::complex<NV> >* sin2(Rstats::Vector2<std::complex<NV> >* v1);
+    Rstats::Vector2<NV>* sin2(Rstats::Vector2<NV>* v1);
+    Rstats::Vector2<NV>* sin2(Rstats::Vector2<IV>* v1);
+        
     std::vector<SV*>* get_character_values(Rstats::Vector*);
     std::vector<std::complex<NV> >* get_complex_values(Rstats::Vector*);
     std::vector<NV>* get_double_values(Rstats::Vector*);
@@ -703,14 +770,25 @@ namespace Rstats {
     Rstats::Vector* clone(Rstats::Vector*);
   }
   
-  namespace ArrayFunc {
-    SV* new_array();
-    void set_vector(SV*, Rstats::Vector*);
-    Rstats::Vector* get_vector(SV*);
-    void set_dim(SV*, Rstats::Vector*);
-    Rstats::Vector* get_dim(SV*);
-    SV* c(SV*);
-    SV* to_c(SV*);
+  namespace Func {
+    SV* new_array(SV*);
+    void set_vector(SV*, SV*, Rstats::Vector*);
+    Rstats::Vector* get_vector(SV*, SV*);
+    void set_dim(SV*, SV*, Rstats::Vector*);
+    Rstats::Vector* get_dim(SV*, SV*);
+    SV* c(SV*, SV*);
+    SV* to_c(SV*, SV*);
+    SV* new_null(SV*); /* NULL */
+    SV* new_na(SV*); /* NA */
+    SV* new_nan(SV*); /* NaN */
+    SV* new_inf(SV*); /* Inf */
+    SV* new_false(SV*); /* FALSE */
+    SV* new_true(SV*); /* TRUE */
+    SV* new_character(SV*, SV*);
+    SV* new_double(SV*, SV*);
+    SV* new_complex(SV*, SV*);
+    SV* new_integer(SV*, SV*);
+    SV* new_logical(SV*, SV*);
   }
 }
 
