@@ -2,7 +2,7 @@ package Rstats;
 use strict;
 use warnings;
 
-our $VERSION = '0.0136';
+our $VERSION = '0.0137';
 
 use Rstats::Class;
 
@@ -17,14 +17,20 @@ sub import {
   no strict 'refs';
   my @methods = qw/c se array matrix list data_frame factor ordered/;
   for my $method (@methods) {
-    *{"${class}::$method"} = sub { $r->$method(@_) }
+    no strict 'refs';
+    my $func = \&{"Rstats::Func::$method"};
+
+    *{"${class}::$method"} = sub { $func->($r, @_) }
   }
   *{"${class}::r"} = sub { $r };
   
   # Export none argument methods
   my @methods_no_args = qw/i T TRUE F FALSE NA NaN Inf NULL pi/;
   for my $method (@methods_no_args) {
-    *{"${class}::$method"} = sub () { $r->$method };
+    no strict 'refs';
+    my $func = \&{"Rstats::Func::$method"};
+
+    *{"${class}::$method"} = sub () { $func->($r, @_) };
   }
   
   warnings->unimport('ambiguous');
@@ -77,9 +83,9 @@ B<Rstats is yet experimental release. Uncompatible change will occur without war
   # all methods is called from r
   my $x1 = r->sum(c(1, 2, 3));
   
-  # Register function
-  r->function(my_sum => sub {
-    my ($self, $x1) = @_;
+  # Register helper
+  r->helper(my_sum => sub {
+    my ($r, $x1) = @_;
     
     my $total = 0;
     for my $value ($x1->values) {
